Examples
========

Functioning
-----------

servo

 - Test case really that shows how to use servos, however also quite a useful example

analog

 - Example of how to read an analog pin, map it to a range and use it to control
   an analog output.

arduino

 - Basic example of how to use the arduino profile
 

Aspirational -- ie Not yet functioning
--------------------------------------
Puppy

 - Complex example based on Dagu playful puppy - specifically
   allows said device to be programmed in (a) python (subset)
